==> process-business-rules-springboot-0.10.0-sources.jar: org/acme/travels/Rules2E460E98FBDF296CF50748F35F942A65RuleMethods0.java <==
package org.acme.travels;

import java.util.*;
import org.drools.model.*;
import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import java.time.*;
import java.time.format.*;
import java.text.*;
import org.drools.core.util.*;
import org.acme.travels.Person;
import static org.acme.travels.Rules2E460E98FBDF296CF50748F35F942A65.*;

public class Rules2E460E98FBDF296CF50748F35F942A65RuleMethods0 {

    /**
     * Rule name: Is adult
     */
    public static org.drools.model.Rule rule_Is_32adult() {
        final org.drools.model.Variable<org.acme.travels.Person> var_$person = D.declarationOf(org.acme.travels.Person.class,
                                                                                               DomainClassesMetadata2E460E98FBDF296CF50748F35F942A65.org_acme_travels_Person_Metadata_INSTANCE,
                                                                                               "$person");
        final org.drools.model.BitMask mask_$person = org.drools.model.BitMask.getPatternMask(DomainClassesMetadata2E460E98FBDF296CF50748F35F942A65.org_acme_travels_Person_Metadata_INSTANCE,
                                                                                              "adult");
        org.drools.model.Rule rule = D.rule("org.acme.travels",
                                            "Is adult").attribute(Rule.Attribute.RULEFLOW_GROUP,
                                                                  "person")
                                                       .build(D.pattern(var_$person).expr("6F251A649871E8072C2937D82BA1FABD",
                                                                                          org.acme.travels.P16.LambdaPredicate16847B129C35B2CF5EAB12D123119C4C.INSTANCE,
                                                                                          D.alphaIndexedBy(java.lang.Integer.class,
                                                                                                           org.drools.model.Index.ConstraintType.GREATER_THAN,
                                                                                                           DomainClassesMetadata2E460E98FBDF296CF50748F35F942A65.org_acme_travels_Person_Metadata_INSTANCE.getPropertyIndex("age"),
                                                                                                           org.acme.travels.PD9.LambdaExtractorD96E873624F68CAEB1239CF63531014C.INSTANCE,
                                                                                                           18),
                                                                                          D.reactOn("age")),
                                                              D.on(var_$person).execute(org.acme.travels.PE9.LambdaConsequenceE9E4C5372C9663F495D02325D3D2108F.INSTANCE));
        return rule;
    }
}

==> process-business-rules-springboot-0.11.0-sources.jar: org/acme/travels/Rules2E460E98FBDF296CF50748F35F942A65RuleMethods0.java <==
package org.acme.travels;

import java.util.*;
import org.drools.model.*;
import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import java.time.*;
import java.time.format.*;
import java.text.*;
import org.drools.core.util.*;
import org.acme.travels.Person;
import static org.acme.travels.Rules2E460E98FBDF296CF50748F35F942A65.*;

public class Rules2E460E98FBDF296CF50748F35F942A65RuleMethods0 {

    /**
     * Rule name: Is adult
     */
    public static org.drools.model.Rule rule_Is_32adult() {
        final org.drools.model.Variable<org.acme.travels.Person> var_$person = D.declarationOf(org.acme.travels.Person.class,
                                                                                               DomainClassesMetadata2E460E98FBDF296CF50748F35F942A65.org_acme_travels_Person_Metadata_INSTANCE,
                                                                                               "$person");
        final org.drools.model.BitMask mask_$person = org.drools.model.BitMask.getPatternMask(DomainClassesMetadata2E460E98FBDF296CF50748F35F942A65.org_acme_travels_Person_Metadata_INSTANCE,
                                                                                              "adult");
        org.drools.model.Rule rule = D.rule("org.acme.travels",
                                            "Is adult").attribute(Rule.Attribute.RULEFLOW_GROUP,
                                                                  "person")
                                                       .build(D.pattern(var_$person).expr("6F251A649871E8072C2937D82BA1FABD",
                                                                                          org.acme.travels.P16.LambdaPredicate16847B129C35B2CF5EAB12D123119C4C.INSTANCE,
                                                                                          D.alphaIndexedBy(java.lang.Integer.class,
                                                                                                           org.drools.model.Index.ConstraintType.GREATER_THAN,
                                                                                                           DomainClassesMetadata2E460E98FBDF296CF50748F35F942A65.org_acme_travels_Person_Metadata_INSTANCE.getPropertyIndex("age"),
                                                                                                           org.acme.travels.PD9.LambdaExtractorD96E873624F68CAEB1239CF63531014C.INSTANCE,
                                                                                                           18),
                                                                                          D.reactOn("age")),
                                                              D.on(var_$person).execute(org.acme.travels.PB7.LambdaConsequenceB7AAE31E2F5945243EB2C78B0EDA48E8.INSTANCE));
        return rule;
    }
}
